labelord
========

|license|

Simple toolkit for manipulating the GitHub labels of multiple repositories.

Project is currently in early development phase... Stay tuned!

It also serves as task for students of `CVUT/MI-PYT`_ course.

License
-------

This project is licensed under the MIT License - see the `LICENSE`_ file for more details.

.. _CVUT/MI-PYT: https://github.com/CVUT/MI-PYT
.. _LICENSE: LICENSE
.. |license| image:: https://img.shields.io/badge/license-MIT-blue.svg
    :alt: License
    :target: LICENSE
